This crate provides the core functionality for the crok crate as a library.
Modules
Macros
- cprint
- cprintln
- cprintln_
rule - crok
- Generate
#[test]functions from inline crok scripts. ThePWDfor the script is set to the current directory, which forcargo testis the root of the crate. - cwrite
- cwriteln
- cwriteln_
rule - Print a rule of dashes, optionally with an embedded message.
- println
Structs
- RunError
- Error returned by
try_run_capturedandtry_run_file_captured.
Functions
- run
- Parse and run a crok script string. Output goes to stdout. Panics on failure.
- run_
captured - Parse and run a crok script string. Returns captured output. Panics on failure.
- run_
file - Parse and run a crok script file. Output goes to stdout. Panics on failure.
- run_
file_ captured - Parse and run a crok script file. Returns captured output. Panics on failure.
- run_
with_ path - Parse and run a crok script string. Output goes to stdout. Panics on failure.
- run_
with_ path_ captured - Parse and run a crok script string. Returns captured output. Panics on failure.
- try_
run_ captured - Parse and run a crok script string. Returns
Ok(output)on success, orErr(RunError)with both the error message and captured output on failure. - try_
run_ file_ captured - Parse and run a crok script file. Returns
Ok(output)on success, orErr(RunError)with the error message and captured output on failure.