pub fn format_match_trace_tree(nodes: &[OutputMatchTraceNode]) -> StringExpand description
Pre-order walk with two spaces of indentation per tree level.
pub fn format_match_trace_tree(nodes: &[OutputMatchTraceNode]) -> StringPre-order walk with two spaces of indentation per tree level.